@@ -37,12 +37,12 @@ class IntelOwl:
         """
         if not hasattr(self, "_session"):
             session = requests.Session()
-            if self.certificate is not None:
+            if self.certificate is not True:
                 session.verify = self.certificate
             session.headers.update(
                 {
                     "Authorization": f"Token {self.token}",
-                    "User-Agent": "IntelOwlClient/3.1.2",
+                    "User-Agent": "IntelOwlClient/3.1.3",
                 }
             )
             self._session = session
@@ -586,7 +586,7 @@ class IntelOwl:
     def _get_observable_classification(self, value: str) -> str:
         """Returns observable classification for the given value.\n
         Only following types are supported:
-        ip, domain, url, hash (md5, sha1, sha256)
+        ip, domain, url, hash (md5, sha1, sha256), generic (if no match)
 
         Args:
             value (str):
@@ -597,7 +597,7 @@ class IntelOwl:
                 if value type is not recognized
 
         Returns:
-            str: one of `ip`, `url`, `domain` or `hash`.
+            str: one of `ip`, `url`, `domain`, `hash` or 'generic'.
         """
         try:
             ipaddress.ip_address(value)
@@ -614,12 +614,15 @@ class IntelOwl:
                 re.match("^[a-f\d]{32}$", value)
                 or re.match("^[a-f\d]{40}$", value)
                 or re.match("^[a-f\d]{64}$", value)
+                or re.match("^[A-F\d]{32}$", value)
+                or re.match("^[A-F\d]{40}$", value)
+                or re.match("^[A-F\d]{64}$", value)
             ):
                 classification = "hash"
             else:
-                classification = "general"
+                classification = "generic"
                 self.logger.warning(
-                    f"{value} is neither a domain nor a URL nor a IP not a hash"
+                    "Couldn't detect observable classification, setting as 'generic'..."
                 )
         else:
             # its a simple IP
